.. AUTO-GENERATED FILE -- DO NOT EDIT!

devices.monitoredqueue
======================

Module: :mod:`devices.monitoredqueue`
-------------------------------------
.. automodule:: zmq.devices.monitoredqueue

.. currentmodule:: zmq.devices.monitoredqueue

.. autofunction:: zmq.devices.monitoredqueue.monitored_queue

